* REPLICATION FILE FOR PROBIT MODELS IN APPENDIX 
* KRISTIN KANTHAK AND JONATHAN WOON 
* "WOMEN DON'T RUN? ELECTION AVERSION AND CANDIDATE ENTRY"
* AMERICAN JOURNAL OF POLITICAL SCIENCE 
* JULY 8, 2014

use wdr2-game, clear

* NOTE: SCORE IS MEAN ADJUSTED SO THAT THE INTERCEPTS ARE MEANINGFUL WHEN THERE ARE INTERACTIONS
egen avg_all = mean(spiece)
gen score = spiece - avg_all

ren volunteer choice_vol
ren run choice_run
gen subid = 100*session + 10*group + id
reshape long choice_, i(subid) j(part, str)
ren choice_ choice

gen nwilling = numcands if part=="run"
replace nwilling = numvols if part=="vol"
gen avg_other = avg_group if (part=="run" & numcands==0) | (part=="vol" & numvols==0)
replace avg_other = avg_cand if part=="run" & numcands>0
replace avg_other = avg_vol if part=="vol" & numvols>0

gen vcb = (treat=="ChatCB" | treat=="TruthCB") & part=="vol"
gen vno = (treat=="ChatNO" | treat=="TruthNO") & part=="vol"
gen ccb = treat=="ChatCB" & part=="run"
gen cno = treat=="ChatNO" & part=="run"
gen tcb = treat=="TruthCB" & part=="run"
gen tno = treat=="TruthNO" & part=="run"

gen s_vcb = score*vcb
gen s_vno = score*vno
gen s_ccb = score*ccb
gen s_cno = score*cno
gen s_tcb = score*tcb
gen s_tno = score*tno

* CHECK ROBUSTNESS TO EXCLUDING SESSIONS WITH UNEQUAL SUBJECTS

gen unequal = session==15 | session==9 | session==17 | session==18

probit choice score vcb ccb cno tcb tno if female==0 & !unequal, cluster(subid)
est sto m1r
probit choice score vcb ccb cno tcb tno if female==1 & !unequal, cluster(subid)
est sto f1r

probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other if female==0 & !unequal, cluster(subid)
est sto m2r
probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other if female==1 & !unequal, cluster(subid)
est sto f2r

probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other s_vcb s_ccb s_cno s_tcb s_tno if female==0 & !unequal, cluster(subid)
est sto m3r
probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other s_vcb s_ccb s_cno s_tcb s_tno if female==1 & !unequal, cluster(subid)
est sto f3r

est table m1r m2r m3r f1r f2r f3r, b(%3.2f) star(.05 .01 .001) stat(ll N)
est table m1r m2r m3r f1r f2r f3r, b(%3.2f) se(%3.2f) stat(ll N)

* CHECK ROBUSTNESS TO INCLUDING DEMOGRAPHIC VARIABLES

tab ambition
recode ambition 5=4
replace ambition = 4-ambition
label values ambition
tab ambition

gen dem = party==1
gen rep = party==2

replace polideo = polideo-3

probit choice score vcb ccb cno tcb tno ambition polideo dem rep if female==0, cluster(subid)
est sto m1d
probit choice score vcb ccb cno tcb tno ambition polideo dem rep if female==1, cluster(subid)
est sto f1d

probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other ambition polideo dem rep if female==0, cluster(subid)
est sto m2d
probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other ambition polideo dem rep if female==1, cluster(subid)
est sto f2d

probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other s_vcb s_ccb s_cno s_tcb s_tno ambition polideo dem rep if female==0, cluster(subid)
est sto m3d
probit choice score vcb ccb cno tcb tno nsafe nwilling avg_other s_vcb s_ccb s_cno s_tcb s_tno ambition polideo dem rep if female==1, cluster(subid)
est sto f3d

est table m1d m2d m3d f1d f2d f3d, b(%3.2f) star(.05 .01 .001) stat(ll N)
est table m1d m2d m3d f1d f2d f3d, b(%3.2f) se(%3.2f) stat(ll N)
